@@ -8,4 +8,9 @@ __all__ = ["motd",
            "install",
            "auth",
            "deploy",
-           "manage"]
+           "manage",
+           "event",
+           "sync",
+           "updateui",
+           "handoff",
+           "register_samplers"]
